import { create } from 'zustand';
import { client, query } from '@/modules/query';
import { toast } from 'react-toastify';
export type Package = {
  id: string;
  name?: string;
  version?: string;
  description?: string;
  title?: string;
  user?: string;
  key?: string;
};

type PackageStore = {
  installedPackages: Package[];
  shopPackages: Package[];
  setInstalledPackages: (packages: Package[]) => void;
  setShopPackages: (packages: Package[]) => void;
  getInstalledPackages: () => Promise<Package[]>;
  getShopPackages: () => Promise<Package[]>;
  uninstallPackage: (pkg: Package) => Promise<void>;
  installPackage: (pkg: Package) => Promise<void>;
};
export const usePackageStore = create<PackageStore>((set, get) => ({
  installedPackages: [],
  shopPackages: [],
  setInstalledPackages: (packages) => set({ installedPackages: packages }),
  setShopPackages: (packages) => set({ shopPackages: packages }),
  getInstalledPackages: async () => {
    const res = await client.post({
      path: 'shop',
      key: 'list-installed',
    });
    if (res.code === 200) {
      set({ installedPackages: res.data });
    }
    return res.data;
  },
  getShopPackages: async () => {
    // path=app&key=public-list
    const res = await query.post(
      {
        path: 'app',
        key: 'public-list',
      },
      {
        url: 'https://kevisual.silkyai.cn/api/router',
      },
    );
    if (res.code === 200) {
      set({ shopPackages: res.data });
    }
    return res.data;
  },
  uninstallPackage: async (pkg: Package) => {
    const res = await client.post({
      path: 'shop',
      key: 'uninstall',
      data: { pkg },
    });
    if (res.code === 200) {
      get().getInstalledPackages();
      toast.success('Package uninstalled successfully');
    } else {
      toast.error(res.message || 'Failed to uninstall package');
    }
    console.log('uninstallPackage', res);
  },
  installPackage: async (pkg: Package) => {
    const toastId = toast.loading('Installing package...');
    const res = await client.post({
      path: 'shop',
      key: 'install',
      data: { pkg },
    });
    toast.dismiss(toastId);
    if (res.code === 200) {
      get().getInstalledPackages();
      toast.success('Package installed successfully');
    } else {
      toast.error(res.message || 'Failed to install package');
    }
    console.log('installPackage', res);
  },
}));

const installedPackages: Package[] = [
  { user: 'test', key: 'test-key', version: '1.0.0', id: '1', title: '', description: '' },
  { user: 'demo', key: 'demo-package', version: '1.2.0', id: '2', title: '', description: '' },
];

const mockPackages: Package[] = [
  {
    id: '1',
    title: 'Demo Package 1',
    description: 'A test package for demonstration',
    version: '1.0.0',
    user: 'test',
    key: 'test-key',
  },
  {
    id: '2',
    title: 'Demo Package 2',
    description: 'Another test package with updates',
    version: '2.0.0',
    user: 'demo',
    key: 'demo-package',
  },
  {
    id: '3',
    title: 'New Package',
    description: "A package that hasn't been installed yet",
    version: '1.0.0',
    user: 'demo',
    key: 'new-package',
  },
];
